# grad-gpad :moyai: [![version](https://img.shields.io/github/release/acostapazo/gradgpad/all.svg)](https://github.com/acostapazo/gradgpad/releases) [![ci](https://github.com/acostapazo/gradgpad/workflows/ci/badge.svg)](https://github.com/acostapazo/gradgpad/actions) [![pypi](https://img.shields.io/pypi/dm/gradgpad)](https://pypi.org/project/gradgpad/)


Insert project description here

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://github.com/acostapazo/gradgpad/blob/master/notebooks/reproducible-research.ipynb)


## Table of Contents
- [Installation :computer:](#installation-computer)
- [Reproducible Research :computer:](#reproducible-research-computer)
- [Getting Started :computer:](#reproducible-research-computer)
- [Testing :white_check_mark:](#testing-white_check_mark)
- [Contact :mailbox_with_mail:](#contact-mailbox_with_mail)


## Installation :computer:

```console
pip install gradgpad
```

## Reproducible Research

```console
$ gradgpad --reproducible-research -o <output-folder> 
```

Use `gradgpad --help` to check available parameter

```
$ gradgpad --help                         
usage: gradgpad [-h] [--reproducible-research] [--zip]
                [--output-path OUTPUT_PATH]

optional arguments:
  -h, --help            show this help message and exit
  --reproducible-research, -rr
                        Create a folder with reproducible research results
  --zip, -z             Zip result folder
  --output-path OUTPUT_PATH, -o OUTPUT_PATH
                        Output path
```

## Getting Started 


## Testing :white_check_mark:

### Unit, Integration and Acceptance

```console
(myenv) >> lume -test
```


## Contact :mailbox_with_mail:

support@alicebiometrics.com

